@@ -11,6 +11,7 @@ __all__ = [
 import os
 from binascii import hexlify
 from datetime import datetime
+from base64 import urlsafe_b64encode
 
 from passlib.apps import custom_app_context as pwd_context
 
@@ -176,6 +177,20 @@ class User(Base, BaseMixin):
         """
         
         return {'username': self.username}
+
+    @property
+    def preferred_email(self):
+        return (Email.query.filter_by(user=self, is_preferred=True).first()
+                or Email.query.filter_by(user=self).first())
+
+    @preferred_email.setter
+    def preferred_email(self, email):
+        for e in self.emails:
+            if e is not email:
+                e.is_preferred = False
+        email.is_preferred = True
+        if not email in self.emails:
+            self.emails.append(email)
     
 
 class Email(Base, BaseMixin):
@@ -189,9 +204,16 @@ class Email(Base, BaseMixin):
     
     confirmation_hash = Column(Unicode(28), default=generate_confirmation_hash)
     is_confirmed = Column(Boolean, default=False)
+    is_preferred = Column(Boolean, default=False)
     
     user_id = Column(Integer, ForeignKey('auth_users.id'))
 
+    @property
+    def confirmation_token(self):
+        encoded_id = urlsafe_b64encode(str(self.id))
+        return '%s/%s' % (encoded_id, self.confirmation_hash)
+
+
 def get_existing_user(cls=User, **kwargs):
     """Get an existing user from the filter ``kwargs`` provided.
       
@@ -236,6 +258,13 @@ def get_existing_email(address, cls=Email):
     query = cls.query.filter_by(address=address)
     return query.first()
 
+
+def get_confirmation_link(request, email):
+    """Return a confirmation link for `email`."""
+    base_url = request.route_url('simpleauth', traverse=('confirm',))
+    return '/'.join([base_url, email.confirmation_token])
+
+
 def authenticate(username, raw_password):
     """Get an authenticated user corresponding to the credentials provided.
       
