@@ -25,7 +25,10 @@ class AuthRoot(object):
     __name__ = None
     
     __acl__ = [
-        (Allow, Everyone, 'logout')
+        (Allow, Everyone, 'logout'),
+        (Allow, Authenticated, 'change_password'),
+        (Allow, Authenticated, 'change_username'),
+        (Allow, Authenticated, 'prefer_email'),
     ]
     
     def __init__(self, request):
